@@ -94,6 +94,7 @@ free_stream_data (StreamData *sdata, gboolean remove)
 		connection_list = g_slist_remove (connection_list, sdata);
 		g_object_set_data (G_OBJECT (sdata->doc), "connection_list", connection_list);
 	}
+	g_object_ref (sdata->stream);
 	html_stream_close(sdata->stream);
 	
 	g_free (sdata);
@@ -194,7 +195,7 @@ on_submit (HtmlDocument *document, const gchar *action, const gchar *method,
 	 * start loading a new one, we can't call it directly, because
 	 * gtkhtml2 will crash if the document becomes deleted before
 	 * this signal handler finish */
-	gtk_idle_add (on_submit_idle, ctx);
+	g_idle_add (on_submit_idle, ctx);
 }
 
 static void
